@@ -46,10 +46,10 @@ class setup:
             element.clear()
         element.send_keys(text)
     
-    def get(self, url, parent=None):
+    def get(self, url, check_current_url=True, parent=None):
         if not parent:
             parent = self.driver
-        if parent.current_url != url:
+        if not check_current_url or parent.current_url != url:
             parent.get(url)
 
     def check(self, css_selector, parent=None):
